LexCube - Leipzig Explorer of Earth Data Cubes
Author: Maximilian Söchting
Description: LexCube is an interactive visualization for large-scale earth data sets. Created at Leipzig University by Maximilian Söchting.
Keywords: data cube, earth system data cube, leipzig, esdl, earth system data lab, interactive, visualization, geoscience, remote sensing, geophysics, esa, european space agency

### Animation Settings

Increment per Step:
Visible Window:
Animation Speed:
Total Time: 10.5 s

Cube:
Parameter:
Display Quality:

### ▼ Current Selection

X:
Y:
Z:

### ► Colormap

Value Range:
-
Flip Colormap
Only consider ± 2.5 σ (98.7% of data points)
Starting LexCube...

LexCube is an interactive visualization of large-scale earth data sets. Created at Leipzig University by Maximilian Söchting.
When using Lexcube and generated images acknowledge/cite: M. Söchting, M. D. Mahecha, D. Montero and G. Scheuermann, "Lexcube: Interactive Visualization of Large Earth System Data Cubes," in IEEE Computer Graphics and Applications, vol. 44, no. 1, pp. 25-37, Jan.-Feb. 2024, doi: 10.1109/MCG.2023.3321989.
Client Version: <%= htmlWebpackPlugin.options.version %> (Commit: <%= htmlWebpackPlugin.options.commitDate %>, Build: <%= htmlWebpackPlugin.options.buildDate %>)

## LexCube: How to Use

1. Drag and scroll on the background to move and rotate the cube.
2. Drag and scroll on the cube to interact with the data.
Your browser does not support the video tag.
1. Touch and drag on the background to move and rotate the cube.
2. Touch and drag on the cube to interact with the data.
Your browser does not support the video tag.
Building your own data cube...

# Craft Your Data Cube!

Print🖨️, fold📃, cut✂️ and glue🩹 to make your own crafted data cube. 🧊
Download SVG Download PNG Add custom note